package jdk.internal.instrumentation;

import jdk.internal.org.objectweb.asm.MethodVisitor;
import java.util.HashMap;
import jdk.internal.org.objectweb.asm.ClassVisitor;

final class MaxLocalsTracker extends ClassVisitor
{
    private final HashMap<String, Integer> maxLocalsMap;
    
    public MaxLocalsTracker() {
        super(327680);
        this.maxLocalsMap = new HashMap();
    }
    
    @Override
    public MethodVisitor visitMethod(int n, String s, String s2, String s3, String[] array) {
        return new MaxLocalsTracker.MaxLocalsMethodVisitor(key(s, s2));
    }
    
    public int getMaxLocals(String str, String str2) {
        Integer n = (Integer)this.maxLocalsMap.get(key(str, str2));
        if (n == null) {
            throw new IllegalArgumentException("No maxLocals could be found for " + str + str2);
        }
        return (int)n;
    }
    
    private static String key(String str, String str2) {
        return str + str2;
    }
    
    private final class MaxLocalsMethodVisitor extends MethodVisitor
    {
        private String key;
        
        public MaxLocalsMethodVisitor(String key) {
            super(327680);
            this.key = key;
        }
        
        @Override
        public void visitMaxs(int n, int i) {
            MaxLocalsTracker.this.maxLocalsMap.put(this.key, Integer.valueOf(i));
        }
    }
}
